package com.ruoyi.learn.mapper;

import java.util.List;
import com.ruoyi.learn.domain.LearnDirectedKnowledge;
import org.apache.ibatis.annotations.Param;

/**
 * 定向知识点关系Mapper接口
 * 
 * @author ruoyi
 * @date 2025-09-25
 */
public interface LearnDirectedKnowledgeMapper 
{
    public List<LearnDirectedKnowledge> selectByUniversityIds(@Param("universityIds") Long[] universityIds, @Param("matchYear") Integer matchYear);

    /**
     * 查询定向知识点关系
     * 
     * @param id 定向知识点关系主键
     * @return 定向知识点关系
     */
    public LearnDirectedKnowledge selectLearnDirectedKnowledgeById(Long id);

    /**
     * 查询定向知识点关系列表
     * 
     * @param learnDirectedKnowledge 定向知识点关系
     * @return 定向知识点关系集合
     */
    public List<LearnDirectedKnowledge> selectLearnDirectedKnowledgeList(LearnDirectedKnowledge learnDirectedKnowledge);

    /**
     * 新增定向知识点关系
     * 
     * @param learnDirectedKnowledge 定向知识点关系
     * @return 结果
     */
    public int insertLearnDirectedKnowledge(LearnDirectedKnowledge learnDirectedKnowledge);

    /**
     * 修改定向知识点关系
     * 
     * @param learnDirectedKnowledge 定向知识点关系
     * @return 结果
     */
    public int updateLearnDirectedKnowledge(LearnDirectedKnowledge learnDirectedKnowledge);

    /**
     * 删除定向知识点关系
     * 
     * @param id 定向知识点关系主键
     * @return 结果
     */
    public int deleteLearnDirectedKnowledgeById(Long id);

    /**
     * 批量删除定向知识点关系
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLearnDirectedKnowledgeByIds(Long[] ids);
}
