package com.ruoyi.web.controller.learn;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.learn.domain.LearnDirectedKnowledge;
import com.ruoyi.learn.service.ILearnDirectedKnowledgeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 定向知识点关系Controller
 * 
 * @author ruoyi
 * @date 2025-09-25
 */
@RestController
@RequestMapping("/learn/directKnowledge")
public class LearnDirectedKnowledgeController extends BaseController
{
    @Autowired
    private ILearnDirectedKnowledgeService learnDirectedKnowledgeService;

    /**
     * 查询定向知识点关系列表
     */
    @PreAuthorize("@ss.hasPermi('learn:directKnowledge:list')")
    @GetMapping("/list")
    public TableDataInfo list(LearnDirectedKnowledge learnDirectedKnowledge)
    {
        startPage();
        List<LearnDirectedKnowledge> list = learnDirectedKnowledgeService.selectLearnDirectedKnowledgeList(learnDirectedKnowledge);
        return getDataTable(list);
    }

    /**
     * 导出定向知识点关系列表
     */
    @PreAuthorize("@ss.hasPermi('learn:directKnowledge:export')")
    @Log(title = "定向知识点关系", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LearnDirectedKnowledge learnDirectedKnowledge)
    {
        List<LearnDirectedKnowledge> list = learnDirectedKnowledgeService.selectLearnDirectedKnowledgeList(learnDirectedKnowledge);
        ExcelUtil<LearnDirectedKnowledge> util = new ExcelUtil<LearnDirectedKnowledge>(LearnDirectedKnowledge.class);
        util.exportExcel(response, list, "定向知识点关系数据");
    }

    /**
     * 获取定向知识点关系详细信息
     */
    @PreAuthorize("@ss.hasPermi('learn:directKnowledge:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(learnDirectedKnowledgeService.selectLearnDirectedKnowledgeById(id));
    }

    /**
     * 新增定向知识点关系
     */
    @PreAuthorize("@ss.hasPermi('learn:directKnowledge:add')")
    @Log(title = "定向知识点关系", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LearnDirectedKnowledge learnDirectedKnowledge)
    {
        return toAjax(learnDirectedKnowledgeService.insertLearnDirectedKnowledge(learnDirectedKnowledge));
    }

    /**
     * 修改定向知识点关系
     */
    @PreAuthorize("@ss.hasPermi('learn:directKnowledge:edit')")
    @Log(title = "定向知识点关系", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LearnDirectedKnowledge learnDirectedKnowledge)
    {
        return toAjax(learnDirectedKnowledgeService.updateLearnDirectedKnowledge(learnDirectedKnowledge));
    }

    /**
     * 删除定向知识点关系
     */
    @PreAuthorize("@ss.hasPermi('learn:directKnowledge:remove')")
    @Log(title = "定向知识点关系", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(learnDirectedKnowledgeService.deleteLearnDirectedKnowledgeByIds(ids));
    }
}
